==> haskell-crypto-pubkey-types-0.4.3-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-Acnacid1uvj9ycLSIZdbsB
key:                  crypto-pubkey-types-0.4.3-Acnacid1uvj9ycLSIZdbsB
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  06d879076bf0e040d9127447919be87d
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-pubkey-types-0.4.3
hs-libraries:         HScrypto-pubkey-types-0.4.3-Acnacid1uvj9ycLSIZdbsB
depends:
    asn1-encoding-0.9.6-1hiEaDzNnvZCKkl9Gb4izO
    asn1-types-0.3.4-KHBfkOvXvyLC7EfnO8fkLD base-4.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-types-0.4.3-244-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-pubkey-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-pubkey-types
version:              0.4.3
visibility:           public
id:                   crypto-pubkey-types-0.4.3-1d6p6WhaBtDDmsYF6rxPCZ
key:                  crypto-pubkey-types-0.4.3-1d6p6WhaBtDDmsYF6rxPCZ
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-pubkey-types
synopsis:             Generic cryptography Public keys algorithm types
description:          Generic cryptography public keys algorithm types
category:             Cryptography
abi:                  71941608905e622a97eab061c914c10f
exposed:              True
exposed-modules:
    Crypto.Types.PubKey.DH Crypto.Types.PubKey.DSA
    Crypto.Types.PubKey.ECC Crypto.Types.PubKey.ECDSA
    Crypto.Types.PubKey.RSA

import-dirs:          /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/crypto-pubkey-types-0.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/crypto-pubkey-types-0.4.3
hs-libraries:         HScrypto-pubkey-types-0.4.3-1d6p6WhaBtDDmsYF6rxPCZ
depends:
    asn1-encoding-0.9.6-GST7u8YWSVMBlxeVag7x5g
    asn1-types-0.3.4-7gCtfa0duAqTepdsDJGVJ base-4.15.0.0

haddock-interfaces:
    /usr/share/doc/haskell-crypto-pubkey-types/html/crypto-pubkey-types.haddock

haddock-html:         /usr/share/doc/haskell-crypto-pubkey-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
